@@ -76,6 +76,7 @@ ALL_ROUTES = [
     ('block:snapshot-order', 'SoftLayer.CLI.block.snapshot.order:cli'),
     ('block:snapshot-restore', 'SoftLayer.CLI.block.snapshot.restore:cli'),
     ('block:volume-cancel', 'SoftLayer.CLI.block.cancel:cli'),
+    ('block:volume-count', 'SoftLayer.CLI.block.count:cli'),
     ('block:volume-detail', 'SoftLayer.CLI.block.detail:cli'),
     ('block:volume-duplicate', 'SoftLayer.CLI.block.duplicate:cli'),
     ('block:volume-list', 'SoftLayer.CLI.block.list:cli'),
@@ -100,6 +101,7 @@ ALL_ROUTES = [
     ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
     ('file:snapshot-restore', 'SoftLayer.CLI.file.snapshot.restore:cli'),
     ('file:volume-cancel', 'SoftLayer.CLI.file.cancel:cli'),
+    ('file:volume-count', 'SoftLayer.CLI.file.count:cli'),
     ('file:volume-detail', 'SoftLayer.CLI.file.detail:cli'),
     ('file:volume-duplicate', 'SoftLayer.CLI.file.duplicate:cli'),
     ('file:volume-list', 'SoftLayer.CLI.file.list:cli'),
@@ -208,6 +210,24 @@ ALL_ROUTES = [
     ('hardware:reload', 'SoftLayer.CLI.hardware.reload:cli'),
     ('hardware:credentials', 'SoftLayer.CLI.hardware.credentials:cli'),
     ('hardware:update-firmware', 'SoftLayer.CLI.hardware.update_firmware:cli'),
+    ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
+
+    ('securitygroup', 'SoftLayer.CLI.securitygroup'),
+    ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
+    ('securitygroup:detail', 'SoftLayer.CLI.securitygroup.detail:cli'),
+    ('securitygroup:create', 'SoftLayer.CLI.securitygroup.create:cli'),
+    ('securitygroup:edit', 'SoftLayer.CLI.securitygroup.edit:cli'),
+    ('securitygroup:delete', 'SoftLayer.CLI.securitygroup.delete:cli'),
+    ('securitygroup:rule-list', 'SoftLayer.CLI.securitygroup.rule:rule_list'),
+    ('securitygroup:rule-add', 'SoftLayer.CLI.securitygroup.rule:add'),
+    ('securitygroup:rule-edit', 'SoftLayer.CLI.securitygroup.rule:edit'),
+    ('securitygroup:rule-remove', 'SoftLayer.CLI.securitygroup.rule:remove'),
+    ('securitygroup:interface-list',
+     'SoftLayer.CLI.securitygroup.interface:interface_list'),
+    ('securitygroup:interface-add',
+     'SoftLayer.CLI.securitygroup.interface:add'),
+    ('securitygroup:interface-remove',
+     'SoftLayer.CLI.securitygroup.interface:remove'),
 
     ('sshkey', 'SoftLayer.CLI.sshkey'),
     ('sshkey:add', 'SoftLayer.CLI.sshkey.add:cli'),
@@ -256,6 +276,7 @@ ALL_ALIASES = {
     'lb': 'loadbal',
     'meta': 'metadata',
     'my': 'metadata',
+    'sg': 'securitygroup',
     'server': 'hardware',
     'vm': 'virtual',
     'vs': 'virtual',
